Contributions
*************

Modules that provide useful functionality, but aren't essential to the core networking library, are placed in ``pants.contrib``. These modules provide simple, easy to use implementations of many common protocols, such as HTTP and telnet.

.. toctree::
    
    http
